package com.jiuqi.dna.ide.designer.elements;

import com.jiuqi.dna.ide.designer.DesignerBase;
import com.jiuqi.dna.ide.designer.toolkit.LayoutDataDescriptor;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.Iterator;

/* loaded from: com_jiuqi_dna_ide_designer_elements.jar:com/jiuqi/dna/ide/designer/elements/LayoutDataElement.class */
public class LayoutDataElement implements ILayoutDataElement, Serializable {
    private static final long serialVersionUID = 2764030362350696831L;
    protected transient DesignerBase designer;
    private LayoutDataDescriptor layoutDataDescriptor;
    private IFigureElement figureElement;
    private String name;
    private ArrayList<Property> properties = new ArrayList<>();

    public DesignerBase getDesigner() {
        return this.designer;
    }

    public void setDesigner(DesignerBase designer) {
        this.designer = designer;
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ILayoutDataElement
    public LayoutDataDescriptor getLayoutDataDescriptor() {
        return this.layoutDataDescriptor;
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ILayoutDataElement
    public void setLayoutDataDescriptor(LayoutDataDescriptor layoutDataDescriptor) {
        this.layoutDataDescriptor = layoutDataDescriptor;
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ILayoutDataElement
    public IFigureElement getFigureElement() {
        return this.figureElement;
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ILayoutDataElement
    public void setFigureElement(IFigureElement figureElement) {
        this.figureElement = figureElement;
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ILayoutDataElement
    public String getName() {
        return this.name;
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ILayoutDataElement
    public void setName(String name) {
        this.name = name;
    }

    protected void addProperty(Property property) {
        this.properties.add(property);
    }

    protected Property getProperty(String propertyName) {
        if (propertyName == null) {
            return null;
        }
        Iterator<Property> it = this.properties.iterator();
        while (it.hasNext()) {
            Property prop = it.next();
            if (propertyName.equals(prop.getName())) {
                return prop;
            }
        }
        return null;
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ILayoutDataElement
    public boolean getPropertyBooleanValue(String propertyName) {
        String value = getPropertyStringValue(propertyName);
        return Boolean.getBoolean(value);
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ILayoutDataElement
    public int getPropertyIntValue(String propertyName) {
        int intValue;
        String value = getPropertyStringValue(propertyName);
        try {
            intValue = Integer.parseInt(value);
        } catch (NumberFormatException unused) {
            intValue = -1;
        }
        return intValue;
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ILayoutDataElement
    public String getPropertyStringValue(String propertyName) {
        Property prop = getProperty(propertyName);
        if (prop != null) {
            return prop.getValue();
        }
        return null;
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ILayoutDataElement
    public boolean hasProperty(String propertyName) {
        return (this.layoutDataDescriptor == null || this.layoutDataDescriptor.getPropertyDescriptor(propertyName) == null) ? false : true;
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ILayoutDataElement
    public void removeProperty(String propertyName) {
        this.properties.remove(getProperty(propertyName));
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ILayoutDataElement
    public void setPropertyBooleanValue(String propertyName, boolean propertyValue) {
        setPropertyStringValue(propertyName, Boolean.toString(propertyValue));
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ILayoutDataElement
    public void setPropertyIntValue(String propertyName, int propertyValue) {
        setPropertyStringValue(propertyName, Integer.toString(propertyValue));
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ILayoutDataElement
    public void setPropertyStringValue(String propertyName, String propertyValue) {
        if (!hasProperty(propertyName)) {
            return;
        }
        Property prop = getProperty(propertyName);
        if (prop != null) {
            prop.setValue(propertyValue);
        } else {
            Property prop2 = new Property(propertyName);
            prop2.setValue(propertyValue);
            addProperty(prop2);
        }
        firePropertyChange(propertyName);
    }

    protected void firePropertyChange(String propertyName) {
        if (this.designer != null) {
            this.designer.fireFigureLayoutDataChange(this.figureElement, propertyName);
        }
    }
}
